@@ -144,19 +144,19 @@
 //! [`httpmock`]: https://docs.rs/httpmock/
 //! [`async_std`]: https://docs.rs/async-std/
 //! [`tokio`]: https://docs.rs/tokio/
-mod active_mock;
 pub mod http;
 pub mod matchers;
 mod mock;
 mod mock_server;
 mod mock_set;
+mod mounted_mock;
 mod request;
 mod respond;
 mod response_template;
 mod verification;
 
 pub use mock::{Match, Mock, MockBuilder, Times};
-pub use mock_server::{MockServer, MockServerBuilder};
+pub use mock_server::{MockGuard, MockServer, MockServerBuilder};
 pub use request::Request;
 pub use respond::Respond;
 pub use response_template::ResponseTemplate;
